package org.nakedobjects.applib;

import org.nakedobjects.applib.security.UserMemento;


/**
 * Convenience super class for all classes that wish to interact with the container.
 * 
 * @see org.nakedobjects.applib.DomainObjectContainer
 */
public abstract class AbstractContainedObject {

    // {{ Injected: Container
    private DomainObjectContainer container;

    /**
     * This field is not persisted, nor displayed to the user.
     */
    protected DomainObjectContainer getContainer() {
        return this.container;
    }

    /**
     * Injected by the application container itself.
     */
    public final void setContainer(final DomainObjectContainer container) {
        this.container = container;
    }

    // }}

    // {{ Error/Warning Methods
    /**
     * Display the specified message to the user, in a non-intrusive fashion.
     */
    protected void informUser(String message) {
        container.informUser(message);
    }

    /**
     * Display the specified message as a warning to the user, in a more visible fashion, but without
     * requiring explicit acknowledgement.
     */
    protected void warnUser(String message) {
        container.warnUser(message);
    }

    /**
     * Display the specified message as an error to the user, ensuring that it is acknowledged.
     */
    protected void raiseError(String message) {
        container.raiseError(message);
    }

    // }}

    // {{ Security Methods
    protected UserMemento getUser() {
        return container.getUser();
    }
    // }}
}

// Copyright (c) Naked Objects Group Ltd.
